@@ -1,7 +1,7 @@
 from netbox.forms import NetBoxModelForm
 from tenancy.models import Tenant
 from pyrsistent import v
-from .models import PTUEvent, PTUEventRelation, PTUEventAssignment, PTAppSystem, PTAppSystemAssignment, PTUser, PTWorkstation
+from .models import PTUEvent, PTUEventRelation, PTUEventAssignment, PTAppSystem, PTAppSystemAssignment, PTUsers, PTWorkstations
 from utilities.forms.fields import CommentField
 from utilities.forms import (
     BootstrapMixin, DynamicModelChoiceField)
@@ -57,7 +57,7 @@ class PTAppSystemAssignmentForm(BootstrapMixin, forms.ModelForm):
 
 class PTUsersForm(NetBoxModelForm):
     class Meta:
-        model = PTUser
+        model = PTUsers
         fields = ('name',
                   'sAMAccountName',
                   'status',
@@ -70,6 +70,6 @@ class PTUsersForm(NetBoxModelForm):
 
 class PTWorkstationsForm(NetBoxModelForm):
     class Meta:
-        model = PTWorkstation
+        model = PTWorkstations
         fields = ('name', 'CN', 'DistinguishedName', 'ad_guid', 'ad_description', 'description')
 
