@@ -168,39 +168,40 @@ class PTAppSystemAssignmentDeleteView(generic.ObjectDeleteView):
 
 # PTUsers
 class PTUsersView(generic.ObjectView):
-    queryset = models.PTUser.objects.all()
+    queryset = models.PTUsers.objects.all()
     template_name = 'ptuevents/ptusers_add.html'
 
 
 class PTUsersListView(generic.ObjectListView):
-    queryset = models.PTUser.objects.all()
+    queryset = models.PTUsers.objects.all()
     table = tables.PTUsersTable
 
 
 class PTUsersEditView(generic.ObjectEditView):
-    queryset = models.PTUser.objects.all()
+    queryset = models.PTUsers.objects.all()
     form = forms.PTUsersForm
 
 
 class PTUsersDeleteView(generic.ObjectDeleteView):
-    queryset = models.PTUser.objects.all()
+    queryset = models.PTUsers.objects.all()
 
 
 # PTWorkstations
 
 class PTWorkstationsView(generic.ObjectView):
-    queryset = models.PTWorkstation.objects.all()
+    queryset = models.PTWorkstations.objects.all()
+    template_name = 'ptuevents/ptworkstations.html'
 
 
 class PTWorkstationsListView(generic.ObjectListView):
-    queryset = models.PTWorkstation.objects.all()
+    queryset = models.PTWorkstations.objects.all()
     table = tables.PTWorkstationsTable
 
 
 class PTWorkstationsEditView(generic.ObjectEditView):
-    queryset = models.PTWorkstation.objects.all()
+    queryset = models.PTWorkstations.objects.all()
     form = forms.PTWorkstationsForm
 
 
 class PTWorkstationsDeleteView(generic.ObjectDeleteView):
-    queryset = models.PTWorkstation.objects.all()
+    queryset = models.PTWorkstations.objects.all()
